@@ -79,8 +79,7 @@ class AbstractMessagebus(abc.ABC):
             raise ValueError('Required set unit of work class for handler')
         elif not issubclass(unit_of_work, (AbstractSyncUnitOfWork, AbstractAsyncUnitOfWork)):
             raise TypeError('Unit of work class can be subclass of AbstractSyncUnitOfWork or AbstractAsyncUnitOfWork')
-        if engine is None:
-            raise ValueError('Required set engine for handler')
+
         unit_of_work.validate_engine(engine)
 
         return unit_of_work, repository, engine
